@@ -59,7 +59,7 @@ class LifeguardDriver(statedriver.StateDriver):
 
     def __init__(self, db, poll_frequency=statedriver.POLL_FREQUENCY):
         statedriver.StateDriver.__init__(self, db, poll_frequency)
-        self.imaging_server_id = self.db.imaging_servers.get_id(config.get('server', 'fqdn'))
+        self._imaging_server_id = None
 
         # set up the BMM API for use by machines
         self.api = api.API(db)
@@ -72,6 +72,11 @@ class LifeguardDriver(statedriver.StateDriver):
     def _get_timed_out_machine_names(self):
         return self.db.devices.list_timed_out(self.imaging_server_id)
 
+    @property
+    def imaging_server_id(self):
+        if self._imaging_server_id is None:
+            self._imaging_server_id = self.db.imaging_servers.get_id(config.get('server', 'fqdn'))
+        return self._imaging_server_id
 
 ####
 # Mixins
@@ -241,7 +246,7 @@ class locked_out(statemachine.State):
     The device must be forced out of this state."""
 
 @DeviceStateMachine.state_class
-class troubleshooting(AcceptBasicPleaseRequests, statemachine.State):
+class troubleshooting(AcceptPleaseRequests, statemachine.State):
     """
     This device is in a troubleshooting state and will not timeout.
     A 'please_' event or force state must be used to move the device
@@ -806,6 +811,9 @@ class self_test_running(AcceptBasicPleaseRequests, statemachine.State):
     def on_self_test_ok(self, args):
         self.machine.goto_state(ready)
 
+    def on_failed_self_test(self, args):
+        self.machine.goto_state(failed_self_test)
+
 ####
 # Failure states
 
